@@ -31,16 +31,22 @@ class Game():
 
     def invoke_when_program_starts_callbacks(self):
         for callback in self.when_program_starts_callbacks:
-            if hasattr(callback, 'tags'):
-                for sprite in self.sprite_manager.get_sprites(tags=callback.tags):
+            if hasattr(callback, 'tag'):
+                for sprite in self.sprite_manager.get_sprites(tag=callback.tag):
+                    self.task_runner.run(callback, sprite)
+            elif hasattr(callback, 'sprites'):
+                for sprite in callback.sprites:
                     self.task_runner.run(callback, sprite)
             else:
                 self.task_runner.run(callback)
 
     def invoke_forever_callbacks(self):
         for callback in self.forever_callbacks:
-            if hasattr(callback, 'tags'):
-                for sprite in self.sprite_manager.get_sprites(tags=callback.tags):
+            if hasattr(callback, 'tag'):
+                for sprite in self.sprite_manager.get_sprites(tag=callback.tag):
+                    self.task_runner.run(callback, sprite)
+            elif hasattr(callback, 'sprites'):
+                for sprite in callback.sprites:
                     self.task_runner.run(callback, sprite)
             else:
                 self.task_runner.run(callback)
